@@ -11,6 +11,21 @@ class ODDApiClient(HttpClient):
     def __init__(self, base_url: str) -> None:
         self.base_url = base_url.rstrip('/')
 
+    @validate_schema(models.DataSourceList)
+    def create_data_source(
+            self,
+            data: Union[dict, BaseModel],
+            headers: Optional[Dict] = None,
+            timeout: Optional[int] = None,
+    ):
+        request_data = {
+            'path': '/ingestion/datasources',
+            'data': data,
+            'headers': headers,
+            'timeout': timeout,
+        }
+        return self.post(**request_data)
+
     @validate_schema(models.DataEntityList)
     def post_data_entity_list(
             self,
